//==========================================================================
//	Author				: Cytron Technologies		
//	Project				: Sending Data using RF Module
//	Project description	: The receiver will receive the data(0->F) from transmitter 
//				and display the data on 7-segment display. 
//==========================================================================
//	include
//===================================================================================
#include <pic.h> 

// 	configuration
//===================================================================================
__CONFIG (0x3F32);

//	define
//===================================================================================
#define display		PORTB	

//	function prototype
//===================================================================================
unsigned char uart_rec(void);

//	main function
//===================================================================================
void main(void)
{
	//assign variable
	unsigned char num,no;
										// 7 segment display
	unsigned char _7seg[16]={0b01111111,0b00001101,0b10110111,0b10011111,	//0,1,2,3
							 0b11001101,0b11011011,0b11111011,0b00001111,	//4,5,6,7
							 0b11111111,0b11011111,0b11101111,0b11111001,	//8,9,A,B
							 0b01110011,0b10111101,0b11110011,0b11100011};	//C,D,E,F

	//set I/O input output
	TRISB = 0b00000000;			//configure PORTB as output
		
	//setup USART
	BRGH = 0;					//baud rate low speed option
	SPBRG = 255;				//set boud rate to 1200bps for 20Mhz crystal 
	SPEN = 1;					//enable serial port
	RX9 = 0;					//8-bit reception
	CREN = 1;					//enable reception

	num=0;
	display=_7seg[num];

	while(1)					//infinity loop
	{
		CREN=1;							//enable continuos receive
		if(OERR==0) no=uart_rec();		//receive sata if overrun error free
		else CREN=0;					//if overrun error, disable continuos receive
		
		if((no==0)||(no==1)||(no==2)||(no==3)||		//noise filter
		   (no==4)||(no==5)||(no==6)||(no==7)||		//only accept the data 0-F only
           (no==8)||(no==9)||(no==10)||(no==11)||
 		   (no==12)||(no==13)||(no==14)||(no==15))
			num=no;

		display=_7seg[num]; 
	}
}

//	functions
//===================================================================================
unsigned char uart_rec(void)	//receive uart value
{
	unsigned char rec_data;
	while(RCIF==0);				//wait for data
	rec_data = RCREG;
	return rec_data;			//return the received data 
}



